### Name: predict.rsf
### Title: Random Survival Forest Prediction
### Aliases: predict.rsf
### Keywords: survival tree

### ** Examples

#------------------------------------------------------------
# Example 1:  Veteran's Administration lung cancer data

data(veteran, package = "randomSurvivalForest")
pt.train <- sample(1:nrow(veteran), round(nrow(veteran)*0.80))
veteran.out <- rsf(Surv(time, status) ~ ., forest = TRUE,
                   data = veteran[pt.train , ])
veteran.pred <- predict(veteran.out, veteran[-pt.train , ])

## Not run: 
##D #------------------------------------------------------------
##D # Example 2:  Get out-of-bag error rate using the training
##D # data as test data (pbc example)
##D 
##D data(pbc, package = "randomSurvivalForest")
##D pbc.grow <- rsf(Surv(days, status) ~ ., pbc, nsplit = 3, forest = TRUE)
##D pbc.pred <- predict(pbc.grow, pbc, outcome = "test")
##D cat("GROW error rate  :", round(pbc.grow$err.rate[1000], 3))
##D cat("PRED error rate  :", round(pbc.pred$err.rate, 3))
##D 
##D #------------------------------------------------------------
##D # Example 3:  Verify reproducibility of forest (pbc data)
##D 
##D #primary call
##D data(pbc, package = "randomSurvivalForest")
##D pt.train <- sample(1:nrow(pbc), round(nrow(pbc)*0.50))
##D pbc.out <- rsf(Surv(days, status) ~ ., nsplit = 3, forest = TRUE,
##D                data = pbc[pt.train, ])
##D 
##D #make separate predict calls using the outcome option
##D pbc.train <- predict(pbc.out, pbc[-pt.train, ], outcome = "train")
##D pbc.test <- predict(pbc.out, pbc[-pt.train, ], outcome = "test")
##D 
##D #check forest reproducibilility by comparing predicted survival curves
##D timeInterest <- pbc.out$timeInterest
##D surv.train <- exp(-pbc.train$ensemble)
##D surv.test <- exp(-pbc.test$ensemble)
##D matplot(timeInterest, t(surv.train - surv.test), type = "l")
##D 
##D #test reproducibility by repeating B times
##D #compute l1-difference in predicted survival
##D B <- 25
##D l1.valid <- rep(NA, B)
##D for (b in 1:B) {
##D  cat("Replication:", b, "\n")
##D  pt.train <- sample(1:nrow(pbc), round(nrow(pbc)*0.50))
##D  pbc.out <- rsf(Surv(days, status) ~ ., nsplit = 3, forest = TRUE,
##D                  data = pbc[pt.train, ])
##D  surv.train <- exp(-predict(pbc.out, pbc[-pt.train, ], outcome = "train")$ensemble)
##D  surv.test <- exp(-predict(pbc.out, pbc[-pt.train, ], outcome = "test")$ensemble)
##D  l1.valid <-
##D    mean(apply(abs(surv.train - surv.test), 1, mean, na.rm = TRUE), na.rm = TRUE)
##D }
##D cat("l1-reproducibility:", round(mean(l1.valid, na.rm = TRUE), 3), "\n")
##D 
## End(Not run)



