### Name: vimp
### Title: VIMP for Single or Grouped Variables
### Aliases: vimp
### Keywords: file

### ** Examples

#------------------------------------------------------------------------
# Example of paired-VIMP. 
# Veteran data.

data(veteran, package = "randomSurvivalForest") 
v.out <- rsf(Survrsf(time,status)~., veteran, ntree = 1000, forest = TRUE)
vimp(v.out, c("karno","celltype"))$importance

## Not run: 
##D #------------------------------------------------------------------------
##D # Individual VIMP for data restricted to events only.
##D # PBC data.
##D 
##D data(pbc, package = "randomSurvivalForest") 
##D rsf.out <- rsf(Survrsf(days,status)~., pbc, ntree = 1000,
##D                forest = TRUE, nsplit = 3)
##D o.r <- rev(order(rsf.out$importance))
##D imp <- rsf.out$importance[o.r]
##D imp.events <- rep(0, length(imp))
##D events <- which(rsf.out$cens == 1)
##D imp.events <-
##D  vimp(rsf.out, names(imp), events, joint = FALSE)$importance
##D imp.all <- as.data.frame(cbind(imp.events = imp.events, imp = imp))
##D print(round(imp.all, 3))
##D 
##D #------------------------------------------------------------------------
##D # Estimate variability of VIMP in two ways (PBC data):
##D # (i)  Monte Carlo:  Estimates variability of the procedure
##D # (ii) Bootstrap:    Estimates statistical variability
##D 
##D data(pbc, package = "randomSurvivalForest") 
##D rsf.out <- rsf(Survrsf(days,status)~., pbc, ntree = 1000,
##D                nsplit = 3, forest = TRUE)
##D o.r <- rev(order(rsf.out$importance))
##D imp.names <- names(rsf.out$importance[o.r])
##D subset.index <- 1:nrow(rsf.out$predictors)
##D imp.mc <- imp.boot <- NULL
##D for (k in 1:100) {
##D   cat("iteration:", k , "\n")
##D   imp.mc <-
##D     cbind(imp.mc, vimp(rsf.out, imp.names, joint = FALSE)$importance)
##D   imp.boot <-
##D     cbind(imp.boot, vimp(rsf.out, imp.names,
##D     subset = sample(subset.index, replace = TRUE), joint = FALSE)$importance)
##D }
##D imp.mc <- as.data.frame(cbind(imp.mean = apply(imp.mc, 1, mean),
##D                     imp.sd = apply(imp.mc, 1, sd)))
##D imp.boot <- as.data.frame(cbind(imp.mean = apply(imp.boot, 1, mean),
##D                     imp.sd = apply(imp.boot, 1, sd)))
##D print(round(imp.mc, 3))
##D print(round(imp.boot, 3))
## End(Not run)



